Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/dotnet/runtime.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordotnet-bot <dotnet-bot@microsoft.com>2022-10-13 21:20:06 +0300
committerdotnet-bot <dotnet-bot@microsoft.com>2022-10-13 21:20:06 +0300
commitdb342505c2693b679c89c4088307705db0a59a44 (patch)
treef12e858beea66aea0364dd148c86897f94cf534e
parentf252bc67540841b3e8f6ad074678e939236866ec (diff)
parent075e74ed1356f2e5bb978ac541633ab46e34bf99 (diff)
Merge in 'release/7.0' changes
-rw-r--r--eng/pipelines/coreclr/perf-non-wasm-jobs.yml4
-rw-r--r--src/coreclr/debug/di/divalue.cpp16
-rw-r--r--src/coreclr/debug/di/rspriv.h4
-rw-r--r--src/coreclr/inc/cordebug.idl8
-rw-r--r--src/coreclr/pal/prebuilt/inc/cordebug.h20
-rw-r--r--src/mono/dlls/mscordbi/cordb-value.cpp8
-rw-r--r--src/mono/dlls/mscordbi/cordb-value.h4
-rw-r--r--src/mono/mono/mini/mini-s390x.c3
8 files changed, 33 insertions, 34 deletions
diff --git a/eng/pipelines/coreclr/perf-non-wasm-jobs.yml b/eng/pipelines/coreclr/perf-non-wasm-jobs.yml
index 9cc0e60fd01..69479200e24 100644
--- a/eng/pipelines/coreclr/perf-non-wasm-jobs.yml
+++ b/eng/pipelines/coreclr/perf-non-wasm-jobs.yml
@@ -416,7 +416,7 @@ jobs:
nameSuffix: MACiOSAndroidMauiNet7
isOfficialBuild: false
pool:
- vmImage: 'macos-11'
+ vmImage: 'macos-12'
extraStepsTemplate: /eng/pipelines/coreclr/templates/build-perf-maui-apps-net7.yml
extraStepsParameters:
rootFolder: '$(Build.SourcesDirectory)/artifacts/'
@@ -440,7 +440,7 @@ jobs:
nameSuffix: MACiOSAndroidMauiNet6
isOfficialBuild: false
pool:
- vmImage: 'macos-11'
+ vmImage: 'macos-12'
extraStepsTemplate: /eng/pipelines/coreclr/templates/build-perf-maui-apps-net6.yml
extraStepsParameters:
rootFolder: '$(Build.SourcesDirectory)/artifacts/'
diff --git a/src/coreclr/debug/di/rspriv.h b/src/coreclr/debug/di/rspriv.h
index bcad293e339..45169c8470c 100644
--- a/src/coreclr/debug/di/rspriv.h
+++ b/src/coreclr/debug/di/rspriv.h
@@ -9722,8 +9722,8 @@ public:
COM_METHOD GetRank(ULONG32 * pnRank);
COM_METHOD GetCount(ULONG32 * pnCount);
COM_METHOD GetDimensions(ULONG32 cdim, ULONG32 dims[]);
- COM_METHOD HasBaseIndices(BOOL * pbHasBaseIndices);
- COM_METHOD GetBaseIndices(ULONG32 cdim, ULONG32 indices[]);
+ COM_METHOD HasBaseIndicies(BOOL * pbHasBaseIndicies);
+ COM_METHOD GetBaseIndicies(ULONG32 cdim, ULONG32 indices[]);
COM_METHOD GetElement(ULONG32 cdim, ULONG32 indices[], ICorDebugValue ** ppValue);
COM_METHOD GetElementAtPosition(ULONG32 nIndex, ICorDebugValue ** ppValue);
diff --git a/src/coreclr/inc/cordebug.idl b/src/coreclr/inc/cordebug.idl
index 1393913b331..5d8c5e1fa0c 100644
--- a/src/coreclr/inc/cordebug.idl
+++ b/src/coreclr/inc/cordebug.idl
@@ -6805,18 +6805,18 @@ interface ICorDebugArrayValue : ICorDebugHeapValue
length_is(cdim)] ULONG32 dims[]);
/*
- * HasBaseIndices returns whether or not the array has base indices.
+ * HasBaseIndicies returns whether or not the array has base indices.
* If the answer is no, then all dimensions have a base index of 0.
*/
- HRESULT HasBaseIndices([out] BOOL *pbHasBaseIndices);
+ HRESULT HasBaseIndicies([out] BOOL *pbHasBaseIndicies);
/*
- * GetBaseIndices returns the base index of each dimension in
+ * GetBaseIndicies returns the base index of each dimension in
* the array
*/
- HRESULT GetBaseIndices([in] ULONG32 cdim,
+ HRESULT GetBaseIndicies([in] ULONG32 cdim,
[out, size_is(cdim),
length_is(cdim)] ULONG32 indices[]);
diff --git a/src/coreclr/pal/prebuilt/inc/cordebug.h b/src/coreclr/pal/prebuilt/inc/cordebug.h
index 2d71f01fe85..fa4b434eccf 100644
--- a/src/coreclr/pal/prebuilt/inc/cordebug.h
+++ b/src/coreclr/pal/prebuilt/inc/cordebug.h
@@ -15644,10 +15644,10 @@ EXTERN_C const IID IID_ICorDebugArrayValue;
/* [in] */ ULONG32 cdim,
/* [length_is][size_is][out] */ ULONG32 dims[ ]) = 0;
- virtual HRESULT STDMETHODCALLTYPE HasBaseIndices(
- /* [out] */ BOOL *pbHasBaseIndices) = 0;
+ virtual HRESULT STDMETHODCALLTYPE HasBaseIndicies(
+ /* [out] */ BOOL *pbHasBaseIndicies) = 0;
- virtual HRESULT STDMETHODCALLTYPE GetBaseIndices(
+ virtual HRESULT STDMETHODCALLTYPE GetBaseIndicies(
/* [in] */ ULONG32 cdim,
/* [length_is][size_is][out] */ ULONG32 indices[ ]) = 0;
@@ -15722,11 +15722,11 @@ EXTERN_C const IID IID_ICorDebugArrayValue;
/* [in] */ ULONG32 cdim,
/* [length_is][size_is][out] */ ULONG32 dims[ ]);
- HRESULT ( STDMETHODCALLTYPE *HasBaseIndices )(
+ HRESULT ( STDMETHODCALLTYPE *HasBaseIndicies )(
ICorDebugArrayValue * This,
- /* [out] */ BOOL *pbHasBaseIndices);
+ /* [out] */ BOOL *pbHasBaseIndicies);
- HRESULT ( STDMETHODCALLTYPE *GetBaseIndices )(
+ HRESULT ( STDMETHODCALLTYPE *GetBaseIndicies )(
ICorDebugArrayValue * This,
/* [in] */ ULONG32 cdim,
/* [length_is][size_is][out] */ ULONG32 indices[ ]);
@@ -15797,11 +15797,11 @@ EXTERN_C const IID IID_ICorDebugArrayValue;
#define ICorDebugArrayValue_GetDimensions(This,cdim,dims) \
( (This)->lpVtbl -> GetDimensions(This,cdim,dims) )
-#define ICorDebugArrayValue_HasBaseIndices(This,pbHasBaseIndices) \
- ( (This)->lpVtbl -> HasBaseIndices(This,pbHasBaseIndices) )
+#define ICorDebugArrayValue_HasBaseIndicies(This,pbHasBaseIndicies) \
+ ( (This)->lpVtbl -> HasBaseIndicies(This,pbHasBaseIndicies) )
-#define ICorDebugArrayValue_GetBaseIndices(This,cdim,indices) \
- ( (This)->lpVtbl -> GetBaseIndices(This,cdim,indices) )
+#define ICorDebugArrayValue_GetBaseIndicies(This,cdim,indices) \
+ ( (This)->lpVtbl -> GetBaseIndicies(This,cdim,indices) )
#define ICorDebugArrayValue_GetElement(This,cdim,indices,ppValue) \
( (This)->lpVtbl -> GetElement(This,cdim,indices,ppValue) )
diff --git a/src/mono/dlls/mscordbi/cordb-value.cpp b/src/mono/dlls/mscordbi/cordb-value.cpp
index 3078c682eea..d9aa9fa6625 100644
--- a/src/mono/dlls/mscordbi/cordb-value.cpp
+++ b/src/mono/dlls/mscordbi/cordb-value.cpp
@@ -1180,15 +1180,15 @@ HRESULT STDMETHODCALLTYPE CordbArrayValue::GetDimensions(ULONG32 cdim, ULONG32 d
return S_OK;
}
-HRESULT STDMETHODCALLTYPE CordbArrayValue::HasBaseIndices(BOOL* pbHasBaseIndices)
+HRESULT STDMETHODCALLTYPE CordbArrayValue::HasBaseIndicies(BOOL* pbHasBaseIndicies)
{
- LOG((LF_CORDB, LL_INFO100000, "CordbArrayValue - HasBaseIndices - NOT IMPLEMENTED\n"));
+ LOG((LF_CORDB, LL_INFO100000, "CordbArrayValue - HasBaseIndicies - NOT IMPLEMENTED\n"));
return S_OK;
}
-HRESULT STDMETHODCALLTYPE CordbArrayValue::GetBaseIndices(ULONG32 cdim, ULONG32 indices[])
+HRESULT STDMETHODCALLTYPE CordbArrayValue::GetBaseIndicies(ULONG32 cdim, ULONG32 indices[])
{
- LOG((LF_CORDB, LL_INFO100000, "CordbArrayValue - GetBaseIndices - NOT IMPLEMENTED\n"));
+ LOG((LF_CORDB, LL_INFO100000, "CordbArrayValue - GetBaseIndicies - NOT IMPLEMENTED\n"));
return E_NOTIMPL;
}
diff --git a/src/mono/dlls/mscordbi/cordb-value.h b/src/mono/dlls/mscordbi/cordb-value.h
index 0e6ec70b03c..4b2ab5718ad 100644
--- a/src/mono/dlls/mscordbi/cordb-value.h
+++ b/src/mono/dlls/mscordbi/cordb-value.h
@@ -239,8 +239,8 @@ public:
HRESULT STDMETHODCALLTYPE GetRank(ULONG32* pnRank);
HRESULT STDMETHODCALLTYPE GetCount(ULONG32* pnCount);
HRESULT STDMETHODCALLTYPE GetDimensions(ULONG32 cdim, ULONG32 dims[]);
- HRESULT STDMETHODCALLTYPE HasBaseIndices(BOOL* pbHasBaseIndices);
- HRESULT STDMETHODCALLTYPE GetBaseIndices(ULONG32 cdim, ULONG32 indices[]);
+ HRESULT STDMETHODCALLTYPE HasBaseIndicies(BOOL* pbHasBaseIndicies);
+ HRESULT STDMETHODCALLTYPE GetBaseIndicies(ULONG32 cdim, ULONG32 indices[]);
HRESULT STDMETHODCALLTYPE GetElement(ULONG32 cdim, ULONG32 indices[], ICorDebugValue** ppValue);
HRESULT STDMETHODCALLTYPE GetElementAtPosition(ULONG32 nPosition, ICorDebugValue** ppValue);
};
diff --git a/src/mono/mono/mini/mini-s390x.c b/src/mono/mono/mini/mini-s390x.c
index 7c7a936ed97..26e6ba1d32a 100644
--- a/src/mono/mono/mini/mini-s390x.c
+++ b/src/mono/mono/mini/mini-s390x.c
@@ -3594,8 +3594,7 @@ mono_arch_output_basic_block (MonoCompile *cfg, MonoBasicBlock *bb)
break;
case OP_CHECK_THIS: {
/* ensure ins->sreg1 is not NULL */
- s390_lg (code, s390_r0, 0, ins->sreg1, 0);
- s390_ltgr (code, s390_r0, s390_r0);
+ s390_llgc (code, s390_r0, 0, ins->sreg1, 0);
}
break;
case OP_ARGLIST: {
diff --git a/src/coreclr/debug/di/divalue.cpp b/src/coreclr/debug/di/divalue.cpp
index 34937c1a58e..9645ee76526 100644
--- a/src/coreclr/debug/di/divalue.cpp
+++ b/src/coreclr/debug/di/divalue.cpp
@@ -3707,17 +3707,17 @@ HRESULT CordbArrayValue::GetDimensions(ULONG32 cdim, ULONG32 dims[])
//
// indicates whether the array has base indices
// Arguments:
-// output: pbHasBaseIndices - true iff the array has more than one dimension and pbHasBaseIndices is not null
-// Return Value: S_OK on success or E_INVALIDARG if pbHasBaseIndices is null
-HRESULT CordbArrayValue::HasBaseIndices(BOOL *pbHasBaseIndices)
+// output: pbHasBaseIndicies - true iff the array has more than one dimension and pbHasBaseIndicies is not null
+// Return Value: S_OK on success or E_INVALIDARG if pbHasBaseIndicies is null
+HRESULT CordbArrayValue::HasBaseIndicies(BOOL *pbHasBaseIndicies)
{
PUBLIC_REENTRANT_API_ENTRY(this);
FAIL_IF_NEUTERED(this);
- VALIDATE_POINTER_TO_OBJECT(pbHasBaseIndices, BOOL *);
+ VALIDATE_POINTER_TO_OBJECT(pbHasBaseIndicies, BOOL *);
- *pbHasBaseIndices = m_info.arrayInfo.offsetToLowerBounds != 0;
+ *pbHasBaseIndicies = m_info.arrayInfo.offsetToLowerBounds != 0;
return S_OK;
-} // CordbArrayValue::HasBaseIndices
+} // CordbArrayValue::HasBaseIndicies
// gets the base indices for a multidimensional array
// Arguments:
@@ -3725,7 +3725,7 @@ HRESULT CordbArrayValue::HasBaseIndices(BOOL *pbHasBaseIndices)
// indices - an array to hold the base indices for the array dimensions (allocated and managed
// by the caller, it must have space for cdim elements)
// Return Value: S_OK on success or E_INVALIDARG if cdim is not equal to the array rank or indices is null
-HRESULT CordbArrayValue::GetBaseIndices(ULONG32 cdim, ULONG32 indices[])
+HRESULT CordbArrayValue::GetBaseIndicies(ULONG32 cdim, ULONG32 indices[])
{
PUBLIC_REENTRANT_API_ENTRY(this);
FAIL_IF_NEUTERED(this);
@@ -3743,7 +3743,7 @@ HRESULT CordbArrayValue::GetBaseIndices(ULONG32 cdim, ULONG32 indices[])
indices[i] = m_arrayLowerBase[i];
return S_OK;
-} // CordbArrayValue::GetBaseIndices
+} // CordbArrayValue::GetBaseIndicies
// Get an element at the position indicated by the values in indices (one index for each dimension)
// Arguments: